"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BitbucketServerService = void 0;
const lodash_1 = __importDefault(require("lodash"));
const bitbucket_server_api_1 = require("./bitbucket-server.api");
class BitbucketServerService {
    constructor(inputs) {
        this.bitBucketServerApi = new bitbucket_server_api_1.BitbucketServerApi(inputs);
    }
    async getPullRequestsWithCommits(repo, branch) {
        try {
            const repoId = await this.getRepoId(repo);
            const prs = await this.bitBucketServerApi.getPullRequests(repoId, branch);
            return Promise.all(prs.map(async (pr) => {
                const info = await this.bitBucketServerApi.getCommitsInfo(repoId, pr);
                const result = {
                    ...info,
                    prDate: pr.updatedDate || pr.createdDate,
                    number: pr.id,
                    url: `${pr.links.self[0].href}`,
                    title: pr.title,
                };
                return result;
            }));
        }
        catch (error) {
            throw new Error(`failed to get pull requests: ${error.message}`);
        }
    }
    async getBranch(repo, branch) {
        try {
            const repoId = await this.getRepoId(repo);
            const bitBucketBranch = await this.bitBucketServerApi.getBranch(repoId, branch);
            if (!bitBucketBranch) {
                return null;
            }
            return {
                name: branch,
                commit: bitBucketBranch.id,
                commitMsg: bitBucketBranch.message,
                commitURL: bitBucketBranch.commitURL,
                committerUsername: lodash_1.default.get(bitBucketBranch, 'author.emailAddress')
            };
        }
        catch (error) {
            if (lodash_1.default.get(error, 'statusCode') === 404) {
                return;
            }
            throw new Error(`failed to get branch: ${error.message}`);
        }
    }
    async getRepoId(repoInput) {
        const repo = await this.bitBucketServerApi.getRepo(repoInput);
        return `${repo.project.key}/${repo.slug}`;
    }
}
exports.BitbucketServerService = BitbucketServerService;
//# sourceMappingURL=bitbucket-server.service.js.map