"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BitbucketApi = void 0;
const lodash_1 = __importDefault(require("lodash"));
const axios_1 = __importDefault(require("axios"));
class BitbucketApi {
    constructor(inputs) {
        this.serverURL = inputs.bitbucketHost;
        this.username = inputs.bitbucketUsername;
        this.password = inputs.bitbucketPassword;
    }
    async _sendGetRequest(uri, qs) {
        return (0, axios_1.default)({
            url: `${this.serverURL}/${uri}`,
            auth: {
                username: this.username,
                password: this.password,
            },
            params: qs,
        });
    }
    async _getPageByUrl(url) {
        return (0, axios_1.default)({
            url: `${url}`,
            auth: {
                username: this.username,
                password: this.password
            },
        });
    }
    async getBranch(repo, branch) {
        const [workspace, repoSlug] = repo.split('/');
        const result = await this._sendGetRequest(`repositories/${workspace}/${repoSlug}/refs/branches/${branch}`);
        return lodash_1.default.get(result, 'data');
    }
    async getPullRequests(repo, branch) {
        const [workspace, repoSlug] = repo.split('/');
        const result = await this._sendGetRequest(`repositories/${workspace}/${repoSlug}/pullrequests`, {
            pagelen: 50,
            fields: '+values.participants',
            q: `source.branch.name="${branch}"`
        });
        return lodash_1.default.get(result, 'data.values', []);
    }
    async getCommitsInfo(repo, pr) {
        const [workspace, repoSlug] = repo.split('/');
        let result = await this._sendGetRequest(`repositories/${workspace}/${repoSlug}/pullrequests/${pr.id}/commits`);
        const commits = lodash_1.default.get(result, 'data.values', []);
        while (result.data.next) {
            result = await this._getPageByUrl(result.data.next);
            commits.push(...lodash_1.default.get(result, 'data.values', []));
        }
        if (commits.length > 0) {
            const firstCommitDate = commits[0].date;
            const lastCommitDate = lodash_1.default.last(commits).date;
            const commitsByUser = {};
            const committersMap = {};
            for (const commit of commits) {
                const avatar = commit.author.user.links.avatar.href;
                const userName = commit.author.user.nickname;
                committersMap[userName] = {
                    userName,
                    avatar,
                };
                if (!commitsByUser[userName]) {
                    commitsByUser[userName] = [];
                }
                commitsByUser[userName].push({
                    url: commit.links.html.href,
                    userName,
                    sha: commit.hash,
                    message: commit.message,
                    commitDate: commit.date
                });
            }
            return {
                committers: lodash_1.default.values(committersMap),
                commits: lodash_1.default.flatten(lodash_1.default.values(commitsByUser)),
                firstCommitDate,
                lastCommitDate
            };
        }
        return null;
    }
}
exports.BitbucketApi = BitbucketApi;
//# sourceMappingURL=bitbucker.api.js.map