"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BitbucketService = void 0;
const lodash_1 = __importDefault(require("lodash"));
const bitbucker_api_1 = require("./bitbucker.api");
class BitbucketService {
    constructor(inputs) {
        this.bitbucketApi = new bitbucker_api_1.BitbucketApi(inputs);
    }
    async getPullRequestsWithCommits(repo, branch) {
        try {
            const prs = await this.bitbucketApi.getPullRequests(repo, branch);
            return Promise.all(prs.map(async (pr) => {
                const info = await this.bitbucketApi.getCommitsInfo(repo, pr);
                const result = {
                    ...info,
                    prDate: pr.updated_on || pr.created_on,
                    number: pr.id,
                    url: `${pr.links.html.href}`,
                    title: pr.title,
                };
                return result;
            }));
        }
        catch (error) {
            throw new Error(`failed to get pull requests: ${error.message}`);
        }
    }
    async getBranch(repo, branch) {
        try {
            const bitBucketBranch = await this.bitbucketApi.getBranch(repo, branch);
            return {
                name: bitBucketBranch.name,
                commit: bitBucketBranch.target.hash,
                commitMsg: bitBucketBranch.target.message,
                commitURL: bitBucketBranch.target.links.html.href,
                committerUsername: bitBucketBranch.target.author.user.nickname
            };
        }
        catch (error) {
            if (lodash_1.default.get(error, 'status') === 404) {
                return;
            }
            throw new Error(`failed to get branch: ${error.message}`);
        }
    }
}
exports.BitbucketService = BitbucketService;
//# sourceMappingURL=bitbucker.service.js.map