"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitProviders = exports.providers = void 0;
const lodash_1 = __importDefault(require("lodash"));
const github_1 = require("./github");
const bitbucket_1 = require("./bitbucket");
const bitbucket_server_1 = require("./bitbucket-server");
const gitlab_1 = require("./gitlab");
const gerrit_1 = require("./gerrit");
exports.providers = {
    GITHUB: 'github',
    GITHUB_APP: 'github-app',
    BITBUCKET: 'bitbucket',
    BITBUCKET_SERVER: 'bitbucket-server',
    GERRIT: 'gerrit',
    GITLAB: 'gitlab'
};
class GitProviders {
    static get(provider) {
        switch (provider) {
            case exports.providers.GITHUB:
                return github_1.GithubService;
            case exports.providers.GITHUB_APP:
                return github_1.GithubService;
            case exports.providers.BITBUCKET:
                return bitbucket_1.BitbucketService;
            case exports.providers.BITBUCKET_SERVER:
                return bitbucket_server_1.BitbucketServerService;
            case exports.providers.GITLAB:
                return gitlab_1.GitlabService;
            case exports.providers.GERRIT:
                return gerrit_1.GerritService;
            default:
                throw new Error(`Provider ${provider} is not supported`);
        }
    }
    static getTheMostRecentCommit(prs, revision) {
        if (revision) {
            for (const pr of prs) {
                for (const commit of pr.commits) {
                    if (commit.sha === revision) {
                        return commit;
                    }
                }
            }
        }
        const prsSortedByDateAsc = prs.sort((pr1, pr2) => {
            return new Date(pr1.prDate).getTime() - new Date(pr2.prDate).getTime();
        });
        const recentPR = lodash_1.default.last(prsSortedByDateAsc);
        const prCommitsSortedByDateAsc = recentPR.commits.sort((c1, c2) => {
            return new Date(c1.commitDate).getTime() - new Date(c2.commitDate).getTime();
        });
        return lodash_1.default.last(prCommitsSortedByDateAsc);
    }
}
exports.GitProviders = GitProviders;
//# sourceMappingURL=index.js.map