"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.imageEnricherJiraInfo = void 0;
const lodash_1 = __importDefault(require("lodash"));
const chalk_1 = __importDefault(require("chalk"));
const jira_service_1 = require("../api/jira/jira.service");
const codefresh_1 = require("../api/codefresh");
const types_1 = require("../image-enricher-git-info/types");
async function imageEnricherJiraInfo(inputs, linkCallback) {
    console.log('starting jira enricher library');
    console.log(`looking for Issues from message ${inputs.message}`);
    const jiraService = new jira_service_1.JiraService(inputs);
    try {
        await jiraService.init();
    }
    catch (error) {
        throw new Error(`Cant initialize jira client, reason: ${error.message}`);
    }
    const issues = jiraService.extract();
    if (!lodash_1.default.isArray(issues)) {
        if (inputs.failOnNotFound === 'true') {
            throw new Error(`issues weren't found, FAIL_ON_NOT_FOUND=true`);
        }
        console.warn(`issues weren't found, FAIL_ON_NOT_FOUND=false`);
        return;
    }
    else {
        console.log(`detected issues: [${issues.join(', ')}]`);
    }
    for (const issue of issues) {
        const normalizedIssue = issue.toUpperCase();
        console.log(`looking for the issue ${normalizedIssue}`);
        const issueInfo = await jiraService.getInfoAboutIssue(normalizedIssue)
            .catch((error) => console.error(`Can't find jira ticket with number "${normalizedIssue}".\n${error.message}`));
        if (!issueInfo) {
            continue;
        }
        const baseUrl = issueInfo.baseUrl || inputs.jira?.host;
        const url = `${baseUrl}/browse/${normalizedIssue}`;
        const avatarUrls = lodash_1.default.get(issueInfo, 'fields.assignee.avatarUrls', {});
        if (linkCallback) {
            await linkCallback(url);
        }
        const codefreshAPI = new codefresh_1.CodefreshAPI(inputs.cfHost, inputs.cfApiKey);
        const gitopsImageReportingFeature = await codefreshAPI.isGitopsReportingEnabled(inputs.platform);
        if (inputs.platform === types_1.Platform.CLASSIC) {
            await codefreshAPI.createIssueAnnotationClassic(inputs.imageName, {
                number: normalizedIssue,
                url: url,
                title: lodash_1.default.get(issueInfo, 'fields.summary'),
            });
            console.log(chalk_1.default.green(`codefresh assigned issue ${normalizedIssue} to your classic image ${inputs.imageName}`));
        }
        if (inputs.platform === types_1.Platform.GITOPS || gitopsImageReportingFeature) {
            await codefreshAPI.createIssueAnnotation(inputs.imageName, {
                number: normalizedIssue,
                url: url,
                title: lodash_1.default.get(issueInfo, 'fields.summary'),
                assignee: lodash_1.default.get(issueInfo, 'fields.assignee.displayName'),
                status: lodash_1.default.get(issueInfo, 'fields.status.name'),
                avatarURL: Object.values(avatarUrls)[0]
            });
            console.log(chalk_1.default.green(`codefresh assigned issue ${normalizedIssue} to your gitops image ${inputs.imageName}`));
        }
    }
}
exports.imageEnricherJiraInfo = imageEnricherJiraInfo;
//# sourceMappingURL=index.js.map