import _ from 'lodash'
import axios from 'axios'

export class BitbucketApi {
    private readonly serverURL: any
    private readonly username: any
    private readonly password: any

    constructor(inputs) {
        this.serverURL = inputs.bitbucketHost
        this.username = inputs.bitbucketUsername
        this.password = inputs.bitbucketPassword
    }

    async _sendGetRequest(uri, qs?) {
        return axios({
            url: `${this.serverURL}/${uri}`,
            auth: {
                username: this.username,
                password: this.password,
            },
            params: qs,
        })
    }

    async _getPageByUrl(url) {
        return axios({
            url: `${url}`,
            auth: {
                username: this.username,
                password: this.password
            },
        })
    }

    async getBranch(repo, branch) {
        const [ workspace, repoSlug ] = repo.split('/')
        const result = await this._sendGetRequest(`repositories/${workspace}/${repoSlug}/refs/branches/${branch}`)
        return _.get(result, 'data')
    }

    async getPullRequests(repo, branch) {
        const [ workspace, repoSlug ] = repo.split('/')

        const result = await this._sendGetRequest(`repositories/${workspace}/${repoSlug}/pullrequests`, {
            pagelen: 50,
            fields: '+values.participants',
            q: `source.branch.name="${branch}"`
        })
        return _.get(result, 'data.values', [])
    }

    async getCommitsInfo(repo, pr) {
        const [ workspace, repoSlug ] = repo.split('/')
        let result = await this._sendGetRequest(`repositories/${workspace}/${repoSlug}/pullrequests/${pr.id}/commits`)
        const commits = _.get(result, 'data.values', [])
        while (result.data.next) {
            result = await this._getPageByUrl(result.data.next)
            commits.push(..._.get(result, 'data.values', []))
        }

        if (commits.length > 0) {
            const firstCommitDate = commits[0].date
            const lastCommitDate = _.last<any>(commits).date
            const commitsByUser = {}
            const committersMap = {}
            for (const commit of commits) {
                const avatar = commit.author.user.links.avatar.href
                const userName = commit.author.user.nickname
                committersMap[userName] = {
                    userName,
                    avatar,
                }
                if (!commitsByUser[userName]) {
                    commitsByUser[userName] = []
                }
                commitsByUser[userName].push({
                    url: commit.links.html.href,
                    userName,
                    sha: commit.hash,
                    message: commit.message,
                    commitDate: commit.date
                })
            }
            return {
                committers: _.values(committersMap),
                commits: _.flatten(_.values(commitsByUser)),
                firstCommitDate,
                lastCommitDate
            }
        }
        return null
    }
}
