export enum Platform {
  CLASSIC = 'CLASSIC',
  GITOPS = 'GITOPS',
}

export type GitEnricherInputs = {
  provider: string,
  cfHost?: string,
  cfApiKey?: string,
  imageName?: string,
  repo?: string,
  branch?: string,
  revision?: string,
  gitContext?: string,
  eventFilePR?: any,
  platform: Platform,

  // github
  githubApiHost?: string,
  githubToken?: string,
  githubApiPathPrefix?: string,
  githubContextName?: string,

  // github app
  githubAppId?: string,
  githubAppPrivateKey?: string,
  githubAppInstallationId?: string,

  // gitlab
  gitlabHost?: string,
  gitlabToken?: string,

  // bitbucket
  bitbucketHost?: string,
  bitbucketUsername?: string,
  bitbucketPassword?: string,

  // gerrit
  gerritChangeId?: string,
  gerritHost?: string,
  gerritUsername?: string,
  gerritPassword?: string,

  commitsByUserLimit?: string,
}

export type Committer = {
  userName: string,
  avatar?: string
}

export type Commit = {
  url: string,
  userName: string,
  sha: string,
  message: string,
  commitDate: string
}

export type CommitInfo = {
  committers: [Committer],
  commits: [Commit],
  firstCommitDate: string,
  lastCommitDate: string
}

export type BranchInfo = {
  name: string,
  commit: string,
  commitMsg: string,
  commitURL: string,
  committerUsername: string
}

export type PRInfo = {
  committers: [Committer],
  commits: [Commit],
  firstCommitDate: string,
  lastCommitDate: string
  prDate: string
  number: string,
  url: string,
  title: string,
  targetBranch?: string
}
